@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -34,19 +34,12 @@
 
 #include <tools/debug.hxx>
 
-#include <attrib.hxx>
 #include <basobj.hxx>
 #include <module.hxx>
 #include <globals.hxx>
 #include <database.hxx>
 
-/****************** SvMetaObject *****************************************/
 SV_IMPL_META_FACTORY1( SvMetaObject, SvRttiBase )
-/*************************************************************************
-|*    SvMetaObject::SvMetaObject()
-|*
-|*    Beschreibung
-*************************************************************************/
 SvMetaObject::SvMetaObject()
 {
 }
@@ -59,24 +52,13 @@ void SvMetaObject::Save( SvPersistStream & )
 {
 }
 
-/*************************************************************************
-|*    SvMetaObject::WriteTab()
-|*
-|*    Beschreibung
-*************************************************************************/
 #ifdef IDL_COMPILER
-void SvMetaObject::WriteTab( SvStream & rOutStm, USHORT nTab )
+void SvMetaObject::WriteTab( SvStream & rOutStm, sal_uInt16 nTab )
 {
     while( nTab-- )
         rOutStm << "    ";
-//        rOutStm << '\t';
 }
 
-/*************************************************************************
-|*    SvMetaObject::WriteStart()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaObject::WriteStars( SvStream & rOutStm )
 {
     rOutStm << '/';
@@ -85,41 +67,31 @@ void SvMetaObject::WriteStars( SvStream & rOutStm )
     rOutStm << '/' << endl;
 }
 
-/*************************************************************************
-|*    SvMetaObject::TestAndSeekSpaceOnly()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaObject::TestAndSeekSpaceOnly( SvStream & rOutStm, ULONG nBegPos )
+sal_Bool SvMetaObject::TestAndSeekSpaceOnly( SvStream & rOutStm, sal_uLong nBegPos )
 {
-    // keine leeren Klammern schreiben
-    ULONG nPos = rOutStm.Tell();
+    // write no empty brackets
+    sal_uLong nPos = rOutStm.Tell();
     rOutStm.Seek( nBegPos );
-    BOOL bOnlySpace = TRUE;
+    sal_Bool bOnlySpace = sal_True;
     while( bOnlySpace && rOutStm.Tell() < nPos )
     {
         char c;
         rOutStm >> c;
         if( !isspace( c ) )
-            bOnlySpace = FALSE;
+            bOnlySpace = sal_False;
     }
     if( bOnlySpace )
-        // nichts geschrieben
+        // nothing written
         rOutStm.Seek( nBegPos );
     else
         rOutStm.Seek( nPos );
     return bOnlySpace;
 }
 
-/*************************************************************************
-|*    SvMetaObject::Back2Delemitter()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaObject::Back2Delemitter( SvStream & rOutStm )
 {
-    // keine leeren Klammern schreiben
-    ULONG nPos = rOutStm.Tell();
+    // write no empty brackets
+    sal_uLong nPos = rOutStm.Tell();
     rOutStm.SeekRel( -1 );
     char c = 0;
     rOutStm >> c;
@@ -136,62 +108,31 @@ void SvMetaObject::Back2Delemitter( SvStream & rOutStm )
         rOutStm.Seek( nPos );
 }
 
-/*************************************************************************
-|*    SvMetaObject::ReadSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaObject::ReadSvIdl( SvIdlDataBase &, SvTokenStream & )
+sal_Bool SvMetaObject::ReadSvIdl( SvIdlDataBase &, SvTokenStream & )
 {
-    return FALSE;
+    return sal_False;
 }
 
-/*************************************************************************
-|*    SvMetaObject::WriteSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-void SvMetaObject::WriteSvIdl( SvIdlDataBase &, SvStream &, USHORT /*nTab */ )
+void SvMetaObject::WriteSvIdl( SvIdlDataBase &, SvStream &, sal_uInt16 /*nTab */ )
 {
 }
 
-/*************************************************************************
-|*    SvMetaObject::Write()
-|*
-|*    Beschreibung
-*************************************************************************/
-void SvMetaObject::Write( SvIdlDataBase &, SvStream &, USHORT /*nTab */,
+void SvMetaObject::Write( SvIdlDataBase &, SvStream &, sal_uInt16 /*nTab */,
                              WriteType, WriteAttribute )
 {
 }
 
-/*************************************************************************
-|*    SvMetaObject::WriteCxx()
-|*
-|*    Beschreibung
-*************************************************************************/
-void SvMetaObject::WriteCxx( SvIdlDataBase &, SvStream &, USHORT /*nTab */ )
+void SvMetaObject::WriteCxx( SvIdlDataBase &, SvStream &, sal_uInt16 /*nTab */ )
 {
 }
 
-/*************************************************************************
-|*    SvMetaObject::WriteHxx()
-|*
-|*    Beschreibung
-*************************************************************************/
-void SvMetaObject::WriteHxx( SvIdlDataBase &, SvStream &, USHORT /*nTab */ )
+void SvMetaObject::WriteHxx( SvIdlDataBase &, SvStream &, sal_uInt16 /*nTab */ )
 {
 }
 
 #endif
 
-/****************** SvMetaName *****************************************/
 SV_IMPL_META_FACTORY1( SvMetaName, SvMetaObject );
-/*************************************************************************
-|*    SvMetaName::SvMetaName()
-|*
-|*    Beschreibung
-*************************************************************************/
 SvMetaName::SvMetaName()
 {
 }
@@ -199,13 +140,13 @@ SvMetaName::SvMetaName()
 void SvMetaName::Load( SvPersistStream & rStm )
 {
     SvMetaObject::Load( rStm );
-    BYTE nMask;
+    sal_uInt8 nMask;
     rStm >> nMask;
 
     if( nMask >= 0x20 )
     {
         rStm.SetError( SVSTREAM_FILEFORMAT_ERROR );
-        DBG_ERROR( "wrong format" );
+        OSL_FAIL( "wrong format" );
         return;
     }
     if( nMask & 0x01 )	rStm >> aName;
@@ -218,7 +159,7 @@ void SvMetaName::Load( SvPersistStream & rStm )
 void SvMetaName::Save( SvPersistStream & rStm )
 {
     SvMetaObject::Save( rStm );
-    BYTE nMask = 0;
+    sal_uInt8 nMask = 0;
     if( aName.IsSet() )			nMask |= 0x01;
     if( aHelpContext.IsSet() )  nMask |= 0x02;
     if( aHelpText.IsSet() )   	nMask |= 0x04;
@@ -233,47 +174,32 @@ void SvMetaName::Save( SvPersistStream & rStm )
     if( nMask & 0x10 ) rStm << aDescription;
 }
 
-/*************************************************************************
-|*
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaName::SetName( const ByteString & rName, SvIdlDataBase * )
+sal_Bool SvMetaName::SetName( const ByteString & rName, SvIdlDataBase * )
 {
     aName = rName;
-    return TRUE;
+    return sal_True;
 }
 
 #ifdef IDL_COMPILER
-/*************************************************************************
-|*    SvMetaName::ReadNameSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaName::ReadNameSvIdl( SvIdlDataBase & rBase,
+sal_Bool SvMetaName::ReadNameSvIdl( SvIdlDataBase & rBase,
                                 SvTokenStream & rInStm )
 {
-    UINT32 nTokPos = rInStm.Tell();
+    sal_uInt32 nTokPos = rInStm.Tell();
     SvToken * pTok = rInStm.GetToken_Next();
 
-    // Modulnamen lesen
+    // read module name
     if( pTok->IsIdentifier() )
         if( SetName( pTok->GetString(), &rBase ) )
-            return TRUE;
+            return sal_True;
 
     rInStm.Seek( nTokPos );
-    return FALSE;
+    return sal_False;
 }
 
-/*************************************************************************
-|*    SvMetaName::ReadSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::ReadAttributesSvIdl( SvIdlDataBase & rBase,
                                       SvTokenStream & rInStm )
 {
-    UINT32 nTokPos = rInStm.Tell();
+    sal_uInt32 nTokPos = rInStm.Tell();
     if( aName.ReadSvIdl( SvHash_Name(), rInStm ) )
     {
         if( !SetName( aName, &rBase ) )
@@ -283,21 +209,12 @@ void SvMetaName::ReadAttributesSvIdl( SvIdlDataBase & rBase,
     aHelpText.ReadSvIdl( rBase, rInStm );
     aConfigName.ReadSvIdl( SvHash_ConfigName(), rInStm );
     aDescription.ReadSvIdl( SvHash_Description(), rInStm );
-/*
-    aHelpContext.ReadSvIdl( GetModule()->GetInfo()->GetHelpContextContainer(),
-                          rInStm );
-*/
 }
 
-/*************************************************************************
-|*    SvMetaName::DoReadContextSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::DoReadContextSvIdl( SvIdlDataBase & rBase,
                                    SvTokenStream & rInStm, char cDel )
 {
-    UINT32 nBeginPos = 0; // kann mit Tell nicht vorkommen
+    sal_uInt32 nBeginPos = 0; // can not happen with Tell
     while( nBeginPos != rInStm.Tell() )
     {
         nBeginPos = rInStm.Tell();
@@ -309,45 +226,25 @@ void SvMetaName::DoReadContextSvIdl( SvIdlDataBase & rBase,
     }
 }
 
-/*************************************************************************
-|*    SvMetaName::ReadSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::ReadContextSvIdl( SvIdlDataBase &, SvTokenStream & )
 {
 }
 
-/*************************************************************************
-|*    SvMetaName::Test()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaName::Test( SvIdlDataBase &, SvTokenStream & )
+sal_Bool SvMetaName::Test( SvIdlDataBase &, SvTokenStream & )
 {
-    return TRUE;
+    return sal_True;
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteContextSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-void SvMetaName::WriteContextSvIdl( SvIdlDataBase &, SvStream &, USHORT )
+void SvMetaName::WriteContextSvIdl( SvIdlDataBase &, SvStream &, sal_uInt16 )
 {
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteDescription()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::WriteDescription( SvStream & rOutStm )
 {
     rOutStm << "<DESCRIPTION>" << endl;
 
     ByteString aDesc( GetDescription() );
-    USHORT nPos = aDesc.Search( '\n' );
+    sal_uInt16 nPos = aDesc.Search( '\n' );
     while ( nPos != STRING_NOTFOUND )
     {
         rOutStm << aDesc.Copy( 0, nPos ).GetBuffer() << endl;
@@ -358,14 +255,9 @@ void SvMetaName::WriteDescription( SvStream & rOutStm )
     rOutStm << aDesc.GetBuffer() << endl << "</DESCRIPTION>" << endl;
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteAttributesIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::WriteAttributesSvIdl( SvIdlDataBase & rBase,
                                        SvStream & rOutStm,
-                                       USHORT nTab )
+                                       sal_uInt16 nTab )
 {
     if( aHelpContext.IsSet() || aHelpText.IsSet() || aConfigName.IsSet() )
     {
@@ -392,18 +284,13 @@ void SvMetaName::WriteAttributesSvIdl( SvIdlDataBase & rBase,
     }
 }
 
-/*************************************************************************
-|*    SvMetaName::ReadSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaName::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm )
+sal_Bool SvMetaName::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm )
 {
-    UINT32 nTokPos = rInStm.Tell();
-    BOOL bOk = TRUE;
+    sal_uInt32 nTokPos = rInStm.Tell();
+    sal_Bool bOk = sal_True;
     if( rInStm.Read( '[' ) )
     {
-        UINT32 nBeginPos = 0; // kann mit Tell nicht vorkommen
+        sal_uInt32 nBeginPos = 0; // can not happen with Tell
         while( nBeginPos != rInStm.Tell() )
         {
             nBeginPos = rInStm.Tell();
@@ -427,23 +314,18 @@ BOOL SvMetaName::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm )
     return bOk;
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::WriteSvIdl( SvIdlDataBase & rBase, SvStream & rOutStm,
-                             USHORT nTab )
+                             sal_uInt16 nTab )
 {
-    ULONG nBeginPos = rOutStm.Tell();
+    sal_uLong nBeginPos = rOutStm.Tell();
     WriteTab( rOutStm, nTab );
     rOutStm << '[' << endl;
-    ULONG nOldPos = rOutStm.Tell();
+    sal_uLong nOldPos = rOutStm.Tell();
     WriteAttributesSvIdl( rBase, rOutStm, nTab +1 );
 
-    // keine leeren Klammern schreiben
+    // write no empty brackets
     if( TestAndSeekSpaceOnly( rOutStm, nOldPos ) )
-        // nichts geschrieben
+        // nothing written
         rOutStm.Seek( nBeginPos );
     else
     {
@@ -458,9 +340,9 @@ void SvMetaName::WriteSvIdl( SvIdlDataBase & rBase, SvStream & rOutStm,
     nOldPos = rOutStm.Tell();
     WriteContextSvIdl( rBase, rOutStm, nTab +1 );
 
-    // keine leeren Klammern schreiben
+    // write no empty brackets
     if( TestAndSeekSpaceOnly( rOutStm, nOldPos ) )
-        // nichts geschrieben
+        // nothing written
         rOutStm.Seek( nBeginPos );
     else
     {
@@ -469,34 +351,29 @@ void SvMetaName::WriteSvIdl( SvIdlDataBase & rBase, SvStream & rOutStm,
     }
 }
 
-/*************************************************************************
-|*    SvMetaName::Write()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
-                           USHORT nTab,
+                           sal_uInt16 nTab,
                          WriteType nT, WriteAttribute nA )
 {
-    ULONG nBeginPos = rOutStm.Tell();
+    sal_uLong nBeginPos = rOutStm.Tell();
     WriteTab( rOutStm, nTab );
     rOutStm << '[' << endl;
-    ULONG nOldPos = rOutStm.Tell();
+    sal_uLong nOldPos = rOutStm.Tell();
     WriteAttributes( rBase, rOutStm, nTab +1, nT, nA );
 
-    // keine leeren Klammern schreiben
-    ULONG nPos = rOutStm.Tell();
+    // write no empty brackets
+    sal_uLong nPos = rOutStm.Tell();
     rOutStm.Seek( nOldPos );
-    BOOL bOnlySpace = TRUE;
+    sal_Bool bOnlySpace = sal_True;
     while( bOnlySpace && rOutStm.Tell() < nPos )
     {
         char c;
         rOutStm >> c;
         if( !isspace( c ) )
-            bOnlySpace = FALSE;
+            bOnlySpace = sal_False;
     }
     if( bOnlySpace )
-        // nichts geschrieben
+        // nothing written
         rOutStm.Seek( nBeginPos );
     else
     {
@@ -506,13 +383,8 @@ void SvMetaName::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
     }
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteAttributes()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::WriteAttributes( SvIdlDataBase &, SvStream & rOutStm,
-                                USHORT nTab,
+                                sal_uInt16 nTab,
                                  WriteType, WriteAttribute )
 {
     if( GetHelpText().IsSet() || GetHelpContext().IsSet() )
@@ -535,26 +407,15 @@ void SvMetaName::WriteAttributes( SvIdlDataBase &, SvStream & rOutStm,
     }
 }
 
-/*************************************************************************
-|*    SvMetaName::WriteContext()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaName::WriteContext( SvIdlDataBase &, SvStream &,
-                                USHORT,
+                                sal_uInt16,
                                  WriteType, WriteAttribute )
 {
 }
 #endif // IDL_COMPILER
 
-/****************** SvMetaReference *****************************************/
 SV_IMPL_META_FACTORY1( SvMetaReference, SvMetaName );
 
-/*************************************************************************
-|*    SvMetaReference::SvMetaReference()
-|*
-|*    Beschreibung
-*************************************************************************/
 SvMetaReference::SvMetaReference()
 {
 }
@@ -563,12 +424,12 @@ void SvMetaReference::Load( SvPersistStream & rStm )
 {
     SvMetaName::Load( rStm );
 
-    BYTE nMask;
+    sal_uInt8 nMask;
     rStm >> nMask;
     if( nMask >= 0x2 )
     {
         rStm.SetError( SVSTREAM_FILEFORMAT_ERROR );
-        DBG_ERROR( "wrong format" );
+        OSL_FAIL( "wrong format" );
         return;
     }
     if( nMask & 0x01 )
@@ -583,29 +444,22 @@ void SvMetaReference::Save( SvPersistStream & rStm )
 {
     SvMetaName::Save( rStm );
 
-    // Maske erstellen
-    BYTE nMask = 0;
+    // create mask
+    sal_uInt8 nMask = 0;
     if( aRef.Is() )
         nMask |= 0x01;
 
-    // Daten schreiben
+    // write data
     rStm << nMask;
     if( nMask & 0x01 ) rStm << aRef;
 }
 
-/**************************************************************************/
-/****************** SvMetaExtern ******************************************/
 SV_IMPL_META_FACTORY1( SvMetaExtern, SvMetaReference );
 
-/*************************************************************************
-|*    SvMetaExtern::SvMetaExtern()
-|*
-|*    Beschreibung
-*************************************************************************/
 SvMetaExtern::SvMetaExtern()
     : pModule( NULL )
-    , bReadUUId( FALSE )
-    , bReadVersion( FALSE )
+    , bReadUUId( sal_False )
+    , bReadVersion( sal_False )
 {
 }
 
@@ -613,56 +467,46 @@ void SvMetaExtern::Load( SvPersistStream & rStm )
 {
     SvMetaReference::Load( rStm );
 
-    BYTE nMask;
+    sal_uInt8 nMask;
     rStm >> nMask;
     if( nMask >= 0x20 )
     {
         rStm.SetError( SVSTREAM_FILEFORMAT_ERROR );
-        DBG_ERROR( "wrong format" );
+        OSL_FAIL( "wrong format" );
         return;
     }
     if( nMask & 0x01 ) rStm >> pModule;
     if( nMask & 0x02 ) rStm >> aUUId;
     if( nMask & 0x04 ) rStm >> aVersion;
-    if( nMask & 0x08 ) bReadUUId = TRUE;
-    if( nMask & 0x10 ) bReadVersion = TRUE;
+    if( nMask & 0x08 ) bReadUUId = sal_True;
+    if( nMask & 0x10 ) bReadVersion = sal_True;
 }
 
 void SvMetaExtern::Save( SvPersistStream & rStm )
 {
     SvMetaReference::Save( rStm );
 
-    // Maske erstellen
-    BYTE nMask = 0;
+    // create mask
+    sal_uInt8 nMask = 0;
     if( pModule )                	nMask |= 0x01;
     if( aUUId != SvGlobalName() )	nMask |= 0x02;
     if( aVersion != SvVersion() )	nMask |= 0x04;
     if( bReadUUId ) 				nMask |= 0x08;
     if( bReadVersion )  			nMask |= 0x10;
 
-    // Daten schreiben
+    // write data
     rStm << nMask;
     if( nMask & 0x01 ) rStm << pModule;
     if( nMask & 0x02 ) rStm << aUUId;
     if( nMask & 0x04 ) rStm << aVersion;
 }
 
-/*************************************************************************
-|*    SvMetaExtern::GetModule()
-|*
-|*    Beschreibung
-*************************************************************************/
 SvMetaModule * SvMetaExtern::GetModule() const
 {
     DBG_ASSERT( pModule != NULL, "module not set" );
     return pModule;
 }
 
-/*************************************************************************
-|*    SvMetaExtern::GetUUId()
-|*
-|*    Beschreibung
-*************************************************************************/
 const SvGlobalName & SvMetaExtern::GetUUId() const
 {
 #ifdef IDL_COMPILER
@@ -673,38 +517,23 @@ const SvGlobalName & SvMetaExtern::GetUUId() const
 }
 
 #ifdef IDL_COMPILER
-/*************************************************************************
-|*    SvMetaExtern::SetModule()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::SetModule( SvIdlDataBase & rBase )
 {
     pModule = (SvMetaModule *)rBase.GetStack().Get( TYPE( SvMetaModule ) );
 }
 
-/*************************************************************************
-|*    SvMetaExtern::ReadAttributesSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::ReadAttributesSvIdl( SvIdlDataBase & rBase,
                                         SvTokenStream & rInStm )
 {
     SvMetaReference::ReadAttributesSvIdl( rBase, rInStm );
     if( aUUId.ReadSvIdl( rBase, rInStm ) )
-        bReadUUId = TRUE;
+        bReadUUId = sal_True;
     if( aVersion.ReadSvIdl( rInStm ) )
-        bReadVersion = TRUE;
+        bReadVersion = sal_True;
 }
 
-/*************************************************************************
-|*    SvMetaExtern::WriteAttributesSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::WriteAttributesSvIdl( SvIdlDataBase & rBase,
-                                         SvStream & rOutStm, USHORT nTab )
+                                         SvStream & rOutStm, sal_uInt16 nTab )
 {
     SvMetaReference::WriteAttributesSvIdl( rBase, rOutStm, nTab );
     if( bReadUUId || bReadVersion )
@@ -727,48 +556,28 @@ void SvMetaExtern::WriteAttributesSvIdl( SvIdlDataBase & rBase,
     }
 }
 
-/*************************************************************************
-|*    SvMetaExtern::ReadSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
-BOOL SvMetaExtern::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm )
+sal_Bool SvMetaExtern::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm )
 {
     SetModule( rBase );
-    GetUUId(); // Id wird angelegt
+    GetUUId(); // id gets created
     return SvMetaReference::ReadSvIdl( rBase, rInStm );
 }
 
-/*************************************************************************
-|*    SvMetaExtern::WriteSvIdl()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::WriteSvIdl( SvIdlDataBase & rBase, SvStream & rOutStm,
-                               USHORT nTab )
+                               sal_uInt16 nTab )
 {
     SvMetaReference::WriteSvIdl( rBase, rOutStm, nTab );
 }
 
-/*************************************************************************
-|*    SvMetaExtern::Write()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
-                        USHORT nTab,
+                        sal_uInt16 nTab,
                          WriteType nT, WriteAttribute nA )
 {
     SvMetaReference::Write( rBase, rOutStm, nTab, nT, nA );
 }
 
-/*************************************************************************
-|*    SvMetaExtern::WriteAttributes()
-|*
-|*    Beschreibung
-*************************************************************************/
 void SvMetaExtern::WriteAttributes( SvIdlDataBase & rBase, SvStream & rOutStm,
-                                     USHORT nTab,
+                                     sal_uInt16 nTab,
                                      WriteType nT, WriteAttribute nA )
 {
     SvMetaReference::WriteAttributes( rBase, rOutStm, nTab, nT, nA );
